==> ocaml_3.10.0.orig.tar.gz: ocaml-3.10.0/ocamlbuild/resource.mli <==
(***********************************************************************)
(*                             ocamlbuild                              *)
(*                                                                     *)
(*  Nicolas Pouillard, Berke Durak, projet Gallium, INRIA Rocquencourt *)
(*                                                                     *)
(*  Copyright 2007 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  All rights reserved.  This file is distributed    *)
(*  under the terms of the Q Public License version 1.0.               *)
(*                                                                     *)
(***********************************************************************)

(* $Id: resource.mli,v 1.1 2007/02/07 08:59:14 ertai Exp $ *)
(* Original author: Nicolas Pouillard *)
open My_std

open Pathname
type env

module Resources : Set.S with type elt = t

module Cache :
  sig
    type suspension

    type build_status =
      | Bbuilt
      | Bcannot_be_built
      | Bnot_built_yet
      | Bsuspension of suspension

    val clean : unit -> unit
    val init : unit -> unit
    val resource_state : t -> build_status
    val resource_changed : t -> unit
    val resource_has_changed : t -> bool
    val resource_is_built : t -> bool
    val resource_built : t -> unit
    val resource_is_failed : t -> bool
    val resource_failed : t -> unit
    val suspend_resource : t -> Command.t -> (unit -> unit) -> t list -> unit
    val resume_resource : t -> unit
    val resume_suspension : suspension -> unit
    val get_optional_resource_suspension : t -> (Command.t * (unit -> unit)) option
    val clear_resource_failed : t -> unit
    val dependencies : t -> Resources.t
    val add_dependency : t -> t -> unit
    val get_digest_for : string -> string option
    val store_digest : string -> string -> unit
    val digest_resource : t -> string
    val print_cache : Format.formatter -> unit -> unit
    val print_dependencies : Format.formatter -> unit -> unit
    val fold_dependencies : (string -> string -> 'a -> 'a) -> 'a -> 'a
  end

val compare : t -> t -> int
val print : Format.formatter -> t -> unit
val clean : t -> unit
val import : string -> t

val matchit : t -> t -> env option
val subst : env -> t -> t
val is_up_to_date : t -> bool
val print_env : Format.formatter -> env -> unit

==> ocaml_3.10.1.orig.tar.gz: ocaml-3.10.1/ocamlbuild/resource.mli <==
(***********************************************************************)
(*                             ocamlbuild                              *)
(*                                                                     *)
(*  Nicolas Pouillard, Berke Durak, projet Gallium, INRIA Rocquencourt *)
(*                                                                     *)
(*  Copyright 2007 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  All rights reserved.  This file is distributed    *)
(*  under the terms of the Q Public License version 1.0.               *)
(*                                                                     *)
(***********************************************************************)

(* $Id: resource.mli,v 1.1.4.5 2007/12/18 08:58:02 ertai Exp $ *)
(* Original author: Nicolas Pouillard *)
open My_std

open Pathname
type resource_pattern
type env

module Resources : Set.S with type elt = t

module Cache :
  sig
    type cache_entry
    type suspension

    type build_status =
      | Bbuilt
      | Bcannot_be_built
      | Bnot_built_yet
      | Bsuspension of suspension

    val clean : unit -> unit
    val resource_state : t -> build_status
    val resource_changed : t -> unit
    val resource_has_changed : t -> bool
    val resource_built : t -> unit
    val resource_failed : t -> unit
    val import_in_build_dir : t -> unit
    val suspend_resource : t -> Command.t -> (unit -> unit) -> t list -> unit
    val resume_resource : t -> unit
    val resume_suspension : suspension -> unit
    val get_optional_resource_suspension : t -> (Command.t * (unit -> unit)) option
    val clear_resource_failed : t -> unit
    val add_dependency : t -> t -> unit
    val fold_dependencies : (string -> string -> 'a -> 'a) -> 'a -> 'a
    val external_is_up_to_date : t -> bool

    (* These are not currently used by others modules. *)
    val dependencies : t -> Resources.t
    val print_cache : Format.formatter -> unit -> unit
    val print_dependencies : Format.formatter -> unit -> unit
  end

val digest : t -> string
val exists_in_source_dir : t -> bool
val exists_in_build_dir : t -> bool
val in_build_dir : t -> t
val in_source_dir : t -> t

val clean_up_links : bool Slurp.entry -> bool Slurp.entry

val compare : t -> t -> int
val print : Format.formatter -> t -> unit
val print_pattern : Format.formatter -> resource_pattern -> unit
val clean : t -> unit
val import : string -> t
val import_pattern : string -> resource_pattern

val matchit : resource_pattern -> t -> env option
val subst : env -> t -> t
val subst_any : env -> t -> t
val subst_pattern : env -> resource_pattern -> t
(* val is_up_to_date : t -> bool *)
val print_env : Format.formatter -> env -> unit
